@@ -2,12 +2,21 @@ use crate::body::Body;
 use crate::fragment::Fragment;
 use crate::trailer::Trailer;
 use std::convert::TryFrom;
+use std::fmt;
+use std::fmt::{Display, Formatter};
 
+/// A collection of user input `CommitMessage` text
 #[derive(Debug, PartialEq, Clone)]
 pub struct Bodies {
     bodies: Vec<Body>,
 }
 
+impl Display for Bodies {
+    fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
+        write!(f, "{}", String::from(self.clone()))
+    }
+}
+
 impl From<Vec<Body>> for Bodies {
     fn from(bodies: Vec<Body>) -> Self {
         Bodies { bodies }
@@ -83,6 +92,24 @@ mod tests {
         )
     }
 
+    #[test]
+    fn it_can_be_formatted() {
+        let bodies = Bodies::from(vec![
+            Body::from("Message Body"),
+            Body::from("Another Message Body"),
+        ]);
+
+        assert_eq!(
+            format!("{}", bodies),
+            String::from(indoc!(
+                "
+                Message Body
+
+                Another Message Body"
+            ))
+        )
+    }
+
     #[test]
     fn it_can_parse_itself_from_an_ast() {
         let bodies = Bodies::from(vec![
